#include "mainwindow.h"
#include "../shared/transfer.h"
#include "../shared/definitions.h"
#include "../shared/session.h"
#include <QApplication>

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    app.setApplicationName("QDL");
    app.setApplicationVersion(VERSION_NUMBER);

    qRegisterMetaType< QList<Transfer*> >("QList<Transfer*>");

    Session session;
    MainWindow window;
    window.show();

    return app.exec();
}
